# demos

Those demos use lightweight BIDS example dataset as input to demonstrate how one
could use those methods section templates.

Pybids and BIDS-matlab are used here mostly as means to fetch some of the
metadata required as input for those templates.

## python

Requires:

- pybids
- chevron: https://github.com/noahmorrison/chevron

## matlab

Requires:

- bids-matlab: https://github.com/bids-standard/bids-matlab.git
- Octache: https://github.com/Remi-Gau/Octache

## javascript

Work in progress

```
npm install mustache --save
```
